<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Test Web App</title>
</head>
<body>

  <!-- These should pass -->
  <a href="/about">About Page</a>
  <a href="http://127.0.0.1:5000/contact">Contact Page</a>
  <a href="#">Hash Link</a>
  <a href="./">Rel Link</a>

  <!-- These should fail -->
  <a href="/dhjaow">Failing Link</a>
  <a href="/login">Login Link</a>
  <a href="/500">500 Error</a>

</body>
</html>